# ya-payment
 Invoicing and Payments is a fundamental area of Yagna Ecosystem functionality. It includes aspects of communication between Requestor, Provider and a selected Payment Platform, which becomes crucial when Activities are executed in the context of negotiated Agreements. Yagna applications must be able to exercise various payment models, and the Invoicing/Payment-related communication is happening in parallel to Activity control communication. To define functional patterns of Requestor/Provider interaction in this area, Payment API is specified.

An important principle of the Yagna Payment API is that the actual payment transactions are hidden behind the Invoice flow. In other words, a Yagna Application on Requestor side isn’t expected to trigger actual payment transactions. Instead it is expected to receive and accept Invoices raised by the Provider - based on Application’s Invoice Accept notifications, the Payment API implementation orchestrates the payment via a configured Payment platform.

**NOTE: This specification is work-in-progress.** 

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.2.0
- Package version: 
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/prekucki/ya-client-python-payment.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/prekucki/ya-client-python-payment.git`)

Then import the package:
```python
import ya_payment
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ya_payment
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import ya_payment
from ya_payment.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost/payment-api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = ya_payment.Configuration(
    host = "http://localhost/payment-api/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: app_key
configuration = ya_payment.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with ya_payment.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ya_payment.ProviderApi(api_client)
    debit_node_id = 'debit_node_id_example' # str | 
timeout = 60 # float | How many seconds server should wait for acknowledgement from the remote party (0 means forever)  (optional) (default to 60)

    try:
        # Cancel Debit Note.
        api_instance.cancel_debit_note(debit_node_id, timeout=timeout)
    except ApiException as e:
        print("Exception when calling ProviderApi->cancel_debit_note: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/payment-api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ProviderApi* | [**cancel_debit_note**](docs/ProviderApi.md#cancel_debit_note) | **POST** /provider/debitNotes/{debitNodeId}/cancel | Cancel Debit Note.
*ProviderApi* | [**cancel_invoice**](docs/ProviderApi.md#cancel_invoice) | **POST** /provider/invoices/{invoiceId}/cancel | Cancel Invoice.
*ProviderApi* | [**get_incoming_payment**](docs/ProviderApi.md#get_incoming_payment) | **GET** /provider/payments/{paymentId} | Get incoming Payment.
*ProviderApi* | [**get_incoming_payments**](docs/ProviderApi.md#get_incoming_payments) | **GET** /provider/payments | Get incoming Payments.
*ProviderApi* | [**get_issued_debit_note**](docs/ProviderApi.md#get_issued_debit_note) | **GET** /provider/debitNotes/{debitNodeId} | Get Debit Note.
*ProviderApi* | [**get_issued_debit_notes**](docs/ProviderApi.md#get_issued_debit_notes) | **GET** /provider/debitNotes | Get Debit Notes issued by this Provider.
*ProviderApi* | [**get_issued_invoice**](docs/ProviderApi.md#get_issued_invoice) | **GET** /provider/invoices/{invoiceId} | Get Invoice.
*ProviderApi* | [**get_issued_invoices**](docs/ProviderApi.md#get_issued_invoices) | **GET** /provider/invoices | Get Invoices issued by this Provider.
*ProviderApi* | [**get_payments_for_issued_debit_note**](docs/ProviderApi.md#get_payments_for_issued_debit_note) | **GET** /provider/debitNotes/{debitNodeId}/payments | Get Payments for Debit Note.
*ProviderApi* | [**get_payments_for_issued_invoice**](docs/ProviderApi.md#get_payments_for_issued_invoice) | **GET** /provider/invoices/{invoiceId}/payments | Get Payments for issued Invoice.
*ProviderApi* | [**get_provider_debit_note_events**](docs/ProviderApi.md#get_provider_debit_note_events) | **GET** /provider/debitNoteEvents | Get Debit Note events.
*ProviderApi* | [**get_provider_invoice_events**](docs/ProviderApi.md#get_provider_invoice_events) | **GET** /provider/invoiceEvents | Get Invoice events.
*ProviderApi* | [**issue_debit_note**](docs/ProviderApi.md#issue_debit_note) | **POST** /provider/debitNotes | Issue a Debit Note.
*ProviderApi* | [**issue_invoice**](docs/ProviderApi.md#issue_invoice) | **POST** /provider/invoices | Issue an Invoice.
*ProviderApi* | [**send_debit_note**](docs/ProviderApi.md#send_debit_note) | **POST** /provider/debitNotes/{debitNodeId}/send | Send Debit Note to Requestor.
*ProviderApi* | [**send_invoice**](docs/ProviderApi.md#send_invoice) | **POST** /provider/invoices/{invoiceId}/send | Send Invoice to Requestor.
*RequestorApi* | [**accept_debit_note**](docs/RequestorApi.md#accept_debit_note) | **POST** /requestor/debitNotes/{debitNodeId}/accept | Accept received Debit Note.
*RequestorApi* | [**accept_invoice**](docs/RequestorApi.md#accept_invoice) | **POST** /requestor/invoices/{invoiceId}/accept | Accept received Invoice.
*RequestorApi* | [**amend_allocation**](docs/RequestorApi.md#amend_allocation) | **PUT** /requestor/allocations/{allocationId} | Amend Allocation.
*RequestorApi* | [**create_allocation**](docs/RequestorApi.md#create_allocation) | **POST** /requestor/allocations | Create Allocation.
*RequestorApi* | [**get_allocation**](docs/RequestorApi.md#get_allocation) | **GET** /requestor/allocations/{allocationId} | Get Allocation.
*RequestorApi* | [**get_allocations**](docs/RequestorApi.md#get_allocations) | **GET** /requestor/allocations | Get Allocations.
*RequestorApi* | [**get_outgoing_payment**](docs/RequestorApi.md#get_outgoing_payment) | **GET** /requestor/payments/{paymentId} | Get outgoing Payment.
*RequestorApi* | [**get_outgoing_payments**](docs/RequestorApi.md#get_outgoing_payments) | **GET** /requestor/payments | Get outgoing Payments.
*RequestorApi* | [**get_payments_for_received_debit_note**](docs/RequestorApi.md#get_payments_for_received_debit_note) | **GET** /requestor/debitNotes/{debitNodeId}/payments | Get Payments for Debit Note.
*RequestorApi* | [**get_payments_for_received_invoice**](docs/RequestorApi.md#get_payments_for_received_invoice) | **GET** /requestor/invoices/{invoiceId}/payments | Get Payments for received Invoice.
*RequestorApi* | [**get_received_debit_note**](docs/RequestorApi.md#get_received_debit_note) | **GET** /requestor/debitNotes/{debitNodeId} | Get Debit Note.
*RequestorApi* | [**get_received_debit_notes**](docs/RequestorApi.md#get_received_debit_notes) | **GET** /requestor/debitNotes | Get Debit Notes received by this Requestor.
*RequestorApi* | [**get_received_invoice**](docs/RequestorApi.md#get_received_invoice) | **GET** /requestor/invoices/{invoiceId} | Get Invoice.
*RequestorApi* | [**get_received_invoices**](docs/RequestorApi.md#get_received_invoices) | **GET** /requestor/invoices | Get Invoices received by this Requestor.
*RequestorApi* | [**get_requestor_debit_note_events**](docs/RequestorApi.md#get_requestor_debit_note_events) | **GET** /requestor/debitNoteEvents | Get Debit Note events.
*RequestorApi* | [**get_requestor_invoice_events**](docs/RequestorApi.md#get_requestor_invoice_events) | **GET** /requestor/invoiceEvents | Get Invoice events.
*RequestorApi* | [**reject_debit_note**](docs/RequestorApi.md#reject_debit_note) | **POST** /requestor/debitNotes/{debitNodeId}/reject | Reject received Debit Note.
*RequestorApi* | [**reject_invoice**](docs/RequestorApi.md#reject_invoice) | **POST** /requestor/invoices/{invoiceId}/reject | Reject received Invoice.
*RequestorApi* | [**release_allocation**](docs/RequestorApi.md#release_allocation) | **DELETE** /requestor/allocations/{allocationId} | Release Allocation.


## Documentation For Models

 - [Acceptance](docs/Acceptance.md)
 - [ActivityPayment](docs/ActivityPayment.md)
 - [AgreementPayment](docs/AgreementPayment.md)
 - [Allocation](docs/Allocation.md)
 - [DebitNote](docs/DebitNote.md)
 - [DebitNoteEvent](docs/DebitNoteEvent.md)
 - [ErrorMessage](docs/ErrorMessage.md)
 - [EventType](docs/EventType.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceEvent](docs/InvoiceEvent.md)
 - [InvoiceStatus](docs/InvoiceStatus.md)
 - [Payment](docs/Payment.md)
 - [Rejection](docs/Rejection.md)
 - [RejectionReason](docs/RejectionReason.md)


## Documentation For Authorization


## app_key

- **Type**: Bearer authentication


## Author




